<?php

namespace Bydedi\Utils;

use Bydedi\Container\ServiceProvider;
use Symfony\Component\DependencyInjection\Reference;

class UtilsServiceProvider extends ServiceProvider
{

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->serviceContainer->register('utils.image.extension', 'Imagine\Gd\Imagine');

        $this->serviceContainer->register('utils.image', 'Bydedi\Utils\Image\Image')
            ->addArgument(new Reference('utils.image.extension'))
            ->addArgument('%app.paths%')
            ->addArgument(new Reference('logger'));

        $this->serviceContainer->register('utils.text', 'Bydedi\Utils\I18n\Text')
            ->addArgument(new Reference('database.connection'));

        $this->serviceContainer->register('utils.mobile_detect', 'Detection\MobileDetect');

        $paths = $this->serviceContainer->getParameter('app.paths');
        $this->serviceContainer->setParameter('utils.pdf.amd64', $paths['base'] . '/vendor/bin/wkhtmltopdf-amd64');
        $this->serviceContainer->setParameter('utils.pdf.i386', $paths['base'] . '/vendor/bin/wkhtmltopdf-amd64');

        $this->serviceContainer->register('utils.pdf', 'Bydedi\Utils\Pdf\Pdf')
            ->addArgument('%utils.pdf.amd64%');
        $this->serviceContainer->register('utils.slugify', 'Cocur\Slugify\Slugify');

        // plugins for template
        $this->serviceContainer->register('template.plugins.txt', 'Bydedi\Utils\TemplatePlugin\TxtPlugin')
            ->addArgument(new Reference('utils.text'))
            ->addTag('app.template_plugin');

        $this->serviceContainer->register('template.plugins.image', 'Bydedi\Utils\TemplatePlugin\ImagePlugin')
            ->addArgument(new Reference('utils.image'))
            ->addTag('app.template_plugin');

        $this->serviceContainer->register('template.plugins.mobile_detect', 'Bydedi\Utils\TemplatePlugin\DevicePlugin')
            ->addArgument(new Reference('utils.mobile_detect'))
            ->addTag('app.template_plugin');
    }
}
